@@ -5,10 +5,13 @@
 #' @param dir_distance_type how directionality in B_ij calculations is dealt with:
 #' \code{"symmetric"} (i.e. undirected graph) or \code{"asymmetric"} (i.e. directed graph). See details.
 #' @param disp_type the formula used to calculate the probabilities in the B_ij matrix.
-#' Use \code{"exponential"} for exponential decay, or \code{"threshold"} for setting a distance threshold.
+#' Use \code{"exponential"} for exponential decay, \code{"threshold"} for setting a distance threshold,
+#' or \code{"leptokurtic"} for leptokurtic dispersal.
 #' @param param_u the upstream dispersal parameter. Must be a numeric value. Only used if \code{dir_distance_type = "asymmetric"}. See details.
 #' @param param_d the downstream dispersal parameter. Must be a numeric value. Only used if \code{dir_distance_type = "asymmetric"}. See details.
 #' @param param the dispersal parameter. Must be a numeric value. Only used if \code{dir_distance_type = "symmetric"}. See details.
+#' @param param_l the parameters for the leptokurtic dispersal mode. Must be a numeric vector of the
+#' type \code{c(sigma_stat, sigma_mob, p)}. See details below.
 #'
 #' @return a square matrix of size length(V(graph)) containing B_ij values.
 #' The matrix is organized with "from" nodes on the columns and "to" nodes on the rows
@@ -19,17 +22,25 @@
 #' The distance between reaches midpoints is calculated for each couple of reaches.
 #' \code{dir_distance_type = "asymmetric"} is to be used when the directionality is relevant.
 #' The distance between reaches midpoints is calculated for each couple of reaches and splitted
-#' between 'upstream travelled' distance and 'downstream travelled' distance
+#' between 'upstream travelled' distance and 'downstream travelled' distance.
+#' When \code{disp_type ="leptokurtic"} is selected, symmetric dispersal is assumed.
 #'
-#' The 'param_u', 'param_d', and 'param' values are interpreted differently based on the formula used to relate distance and probability.
+#' The 'param_u', 'param_d', and 'param' values are interpreted differently based on the formula used to relate distance (d_ij) and probability (B_ij).
 #' When \code{disp_type ="exponential"}, those values are used as the base of the exponential dispersal kernel: B_ij = param^{d_ij}.
 #' When \code{disp_type ="threshold"}, those values are used to define the maximum dispersal length: B_ij = ifelse(d_ij < param, 1, 0).
 #'
+#' When \code{disp_type ="leptokurtic"} is selected, a leptokurtic dispersal kernel is used to calculate B_ij.
+#' A leptokurtic dispersal kernel is a mixture of two zero-centered gaussian distributions with standard deviations
+#' \code{sigma_stat} (static part of the population), and \code{sigma_mob} (mobile part of the population).
+#' The probability of dispersal is calculated as: B_ij = p F(0, sigma_stat, d_ij) + (1-p) F(0, sigma_mob, d_ij)
+#' where F is the upper tail of the gaussian cumulative density function.
+#'
 #' @importFrom dplyr select filter summarize left_join rename mutate rename_with contains matches group_by
 #' @importFrom igraph E V
 #' @importFrom rlang .data
 #' @importFrom reshape2 melt
 #' @importFrom dodgr dodgr_dists
+#' @importFrom stats pnorm
 #'
 #' @examples
 #' library(igraph)
@@ -49,13 +60,14 @@ B_ij_fun <- function(graph,
                      disp_type = "exponential",
                      param_u ,
                      param_d ,
-                     param ) {
+                     param,
+                     param_l) {
 
   # Error messages
   if( !(field_B %in% igraph::vertex_attr_names(graph)) ) stop(
     "'field_B' argument must be a valid vertex attribute in 'graph'")
-  if( !(disp_type %in% c("exponential", "threshold")) ) stop(
-    "'disp_type' must be either 'exponential' or 'threshold'")
+  if( !(disp_type %in% c("exponential", "threshold", "leptokurtic")) ) stop(
+    "'disp_type' must be either 'exponential',  'threshold', or 'leptokurtic'")
 
   # Errors for asymmetric distance
   if( dir_distance_type == "asymmetric"){
@@ -77,9 +89,9 @@ B_ij_fun <- function(graph,
     }}
 
   # Errors for symmetric distance
-  if( dir_distance_type == "symmetric" ) {
+  if( dir_distance_type == "symmetric" & disp_type != "leptokurtic") {
     if( missing(param) | is.na(param) )  stop(
-      "'param' must be specified when dir_distance_type = 'symmetric' (if you do not want to include
+      "'param' or 'param_l' must be specified when dir_distance_type = 'symmetric' (if you do not want to include
       dispersal limitation, set 'B_ij_flag = FALSE' in the function's arguments)")
     if( param < 0  ) stop(
       "'param_u', 'param_d', and 'param' must be > 0")
@@ -88,6 +100,19 @@ B_ij_fun <- function(graph,
         "'param' must be < 1 for disp_type = 'exponential'")
     } }
 
+  # Errors for leptokurtic distance
+  if( disp_type == "leptokurtic" ) {
+    if( missing(param_l) )  stop(
+      "'param_l' must be specified when disp_type = 'leptokurtic' ")
+    if( param_l[1] < 0 | param_l[2] < 0 ) stop(
+      "'param_l[1]' and 'param_l[2]' must be > 1 for disp_type = 'leptokurtic'")
+    if( param_l[3] < 0 | param_l[3] > 1 ) stop(
+      "'param_l[3]' must be in the (0;1) interval for disp_type = 'leptokurtic'")
+
+  }
+
+  # leptokurtic is defined only for simmetric dispersal
+  if(disp_type == "leptokurtic") {dir_distance_type <- "symmetric"}
 
   # Set the directionality for Bij calculations
   graph <- set_B_directionality(graph,
@@ -117,6 +142,18 @@ B_ij_fun <- function(graph,
     # if threshold decay
     if(disp_type == "threshold"){
       Bij_mat = ifelse(Bij_mat <= param, 1, 0) }
+
+    # if leptokurtic decay
+    if(disp_type == "leptokurtic"){
+
+      sigma_stat = param_l[1]
+      sigma_mob = param_l[2]
+      prob = param_l[3]
+
+      Bij_mat =  2 * (prob * stats::pnorm(Bij_mat, mean = 0, sd = sigma_stat, lower.tail = FALSE) +
+        (1 - prob) * stats::pnorm(Bij_mat, mean = 0, sd = sigma_mob, lower.tail = FALSE) )
+    }
+
   }
 
 
